==> kinetophone-0.3.0.tar.gz: kinetophone-0.3.0/src/vox/Kinetophone_vox_view.cpp <==
// Kinetophone_vox_view.cpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#include "Kinetophone_vox_view.hpp"
#include "../base/common.hpp"
#include "../base/error/Error.hpp"
#include <iostream>
#include <string>

using std::cout;
using std::cerr;
using std::endl;
using std::string;

using namespace Roan_trail::Kinetophone;

//
// Constructor/destructor
//

//
// Commands
//

void Kinetophone_vox_view::output_message(const string& message)
{
  cout << message;
}

void Kinetophone_vox_view::output_error(const Error* error)
{
  cerr << error;
}

void Kinetophone_vox_view::output_error(const string& message)
{
  cerr << message;
}

//
// Protected member functions
//

bool Kinetophone_vox_view::mf_invariant(bool check_base_class) const
{
  static_cast<void>(check_base_class); // avoid unused warning

  bool return_value = false;

  return_value = true;
  goto exit_point;

 exit_point:
  return return_value;
}

==> kinetophone-0.5.0.tar.gz: kinetophone-0.5.0/src/vox/Kinetophone_vox_view.cpp <==
// Kinetophone_vox_view.cpp
//
// Copyright 2011-2013 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#include "Kinetophone_vox_view.hpp"
#include <kinetophone/common.hpp>
#include <kinetophone/error/Error.hpp>
#include <iostream>
#include <string>

using std::cout;
using std::cerr;
using std::endl;
using std::string;

using Roan_trail::Kinetophone::Error;
using namespace Roan_trail::Kinetophone_app;

//
// Constructor/destructor
//

//
// Commands
//

void Kinetophone_vox_view::output_message(const string& message)
{
  cout << message;
}

void Kinetophone_vox_view::output_error(const Error* error)
{
  cerr << error;
}

void Kinetophone_vox_view::output_error(const string& message)
{
  cerr << message;
}

//
// Protected member functions
//

bool Kinetophone_vox_view::mf_invariant(bool check_base_class) const
{
  static_cast<void>(check_base_class); // avoid unused warning

  bool return_value = false;

  return_value = true;
  goto exit_point;

 exit_point:
  return return_value;
}
